==> 1.0.0.tar.gz: lib/xbr_gaode_track.dart <==
import 'dart:async';
import 'dart:convert';
import 'package:flutter/services.dart';

import 'core/param.dart';
import 'core/result.dart';

class XbrGaodeTrack {
  static const MethodChannel _channel = MethodChannel('xbr_gaode_track');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  ///初始化猎鹰SDK
  static Future<Result> initTrackSDK({
    required String serviceId,
    int gatherInterval = 5, //采集时间间隔 5s，
    int uploadInterval = 30, //上报时间间隔 上报周期设置为30s： 5～50倍
    int cacheSize = 20, //最大缓存 MB
    int locationMode = LocationMode.HIGHT_ACCURACY, //GPS精度
  }) async {
    final String? json = await _channel.invokeMethod('initGaodeTrackSDK', {
      "gatherInterval": gatherInterval,
      "uploadInterval": uploadInterval,
      "cacheSize": cacheSize,
      "locationMode": locationMode,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///创建终端
  static Future<Result> addTerminal({
    required String terminalName, //终端名称
  }) async {
    final String? json = await _channel.invokeMethod('addTerminal', {
      "terminalName": terminalName,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  /// 创建轨迹
  static Future<Result> addTrack({
    required String terminalId,
  }) async {
    final String? json = await _channel.invokeMethod('addTrack', {
      "terminalId": terminalId,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///轨迹上报
  static Future<Result> startTrack({
    required String terminalId,
    required String trackId,
  }) async {
    final String? json = await _channel.invokeMethod('startTrack', {
      "terminalId": terminalId,
      "trackId": trackId,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///开始采集
  static Future<Result> startGather() async {
    final String? json = await _channel.invokeMethod('startGather');
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///停止采集
  static Future<Result> stopGather() async {
    final String? json = await _channel.invokeMethod('stopGather');
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///停止上报
  static Future<Result> stopTrack() async {
    final String? json = await _channel.invokeMethod('stopTrack');
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///获取终端位置
  static Future<Result> queryLatestPoint({
    required String serviceId,
    required String terminalId,
  }) async {
    final String? json = await _channel.invokeMethod('queryLatestPoint', {
      "serviceId": serviceId,
      "terminalId": terminalId,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///获取指定轨迹
  static Future<Result> queryTerminalTrack({
    required String serviceId,
    required String terminalId,
    required String trackId,
    DateTime? startTime,
    DateTime? endTime,
    int? noising = 0, // 去噪：不启用去噪
    int? bindLoad = 1, // 是否绑路：绑路
    int? accFilter = 0, // 精度过滤：不进行精度过滤
    int? driveMode = DriveMode.DRIVING, // 行驶模式： 当前仅支持驾车模式
    int? disCompensation = 1, // 距离补偿：距离补偿
    int? compensationMeter = 2000, // 距离补偿：这里只有超过2km的点才启用距离补偿
    int? includePoints = 1, // 包含点：结果应该包含轨迹点信息
    int? page = 1, // 返回第1页数据，由于未指定轨迹，分页将失效
    int? limit = 100, // 一页不超过100条
  }) async {
    final String? json = await _channel.invokeMethod('queryLatestPoint', {
      "serviceId": serviceId,
      "terminalId": terminalId,
      "trackId": trackId,
      "startTime": startTime?.millisecond,
      "endTime": endTime?.millisecond,
      "noising": noising,
      "bindLoad": bindLoad,
      "accFilter": accFilter,
      "driveMode": driveMode,
      "disCompensation": disCompensation,
      "compensationMeter": compensationMeter,
      "includePoints": includePoints,
      "page": page,
      "limit": limit,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }
}

==> 2.0.1.tar.gz: lib/xbr_gaode_track.dart <==

part of 'xbr_gaode_location_and_track.dart';

class XbrGaodeTrack {

  ///初始化猎鹰SDK
  static Future<Result> initTrackSDK({
    required String serviceId,
    int gatherInterval = 5, //采集时间间隔 5s，
    int uploadInterval = 30, //上报时间间隔 上报周期设置为30s： 5～50倍
    int cacheSize = 20, //最大缓存 MB
    int locationMode = LocationMode.HIGHT_ACCURACY, //GPS精度
  }) async {
    final String? json = await XbrGaodeLocationAndTrack._methodChannel.invokeMethod('initGaodeTrackSDK', {
      "gatherInterval": gatherInterval,
      "uploadInterval": uploadInterval,
      "cacheSize": cacheSize,
      "locationMode": locationMode,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///创建终端
  static Future<Result> addTerminal({
    required String terminalName, //终端名称
  }) async {
    final String? json = await XbrGaodeLocationAndTrack._methodChannel.invokeMethod('addTerminal', {
      "terminalName": terminalName,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  /// 创建轨迹
  static Future<Result> addTrack({
    required String terminalId,
  }) async {
    final String? json = await XbrGaodeLocationAndTrack._methodChannel.invokeMethod('addTrack', {
      "terminalId": terminalId,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///轨迹上报
  static Future<Result> startTrack({
    required String terminalId,
    required String trackId,
  }) async {
    final String? json = await XbrGaodeLocationAndTrack._methodChannel.invokeMethod('startTrack', {
      "terminalId": terminalId,
      "trackId": trackId,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///开始采集
  static Future<Result> startGather() async {
    final String? json = await XbrGaodeLocationAndTrack._methodChannel.invokeMethod('startGather');
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///停止采集
  static Future<Result> stopGather() async {
    final String? json = await XbrGaodeLocationAndTrack._methodChannel.invokeMethod('stopGather');
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///停止上报
  static Future<Result> stopTrack() async {
    final String? json = await XbrGaodeLocationAndTrack._methodChannel.invokeMethod('stopTrack');
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///获取终端位置
  static Future<Result> queryLatestPoint({
    required String serviceId,
    required String terminalId,
  }) async {
    final String? json = await XbrGaodeLocationAndTrack._methodChannel.invokeMethod('queryLatestPoint', {
      "serviceId": serviceId,
      "terminalId": terminalId,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

  ///获取指定轨迹
  static Future<Result> queryTerminalTrack({
    required String serviceId,
    required String terminalId,
    required String trackId,
    DateTime? startTime,
    DateTime? endTime,
    int? noising = 0, // 去噪：不启用去噪
    int? bindLoad = 1, // 是否绑路：绑路
    int? accFilter = 0, // 精度过滤：不进行精度过滤
    int? driveMode = DriveMode.DRIVING, // 行驶模式： 当前仅支持驾车模式
    int? disCompensation = 1, // 距离补偿：距离补偿
    int? compensationMeter = 2000, // 距离补偿：这里只有超过2km的点才启用距离补偿
    int? includePoints = 1, // 包含点：结果应该包含轨迹点信息
    int? page = 1, // 返回第1页数据，由于未指定轨迹，分页将失效
    int? limit = 100, // 一页不超过100条
  }) async {
    final String? json = await XbrGaodeLocationAndTrack._methodChannel.invokeMethod('queryLatestPoint', {
      "serviceId": serviceId,
      "terminalId": terminalId,
      "trackId": trackId,
      "startTime": startTime?.millisecond,
      "endTime": endTime?.millisecond,
      "noising": noising,
      "bindLoad": bindLoad,
      "accFilter": accFilter,
      "driveMode": driveMode,
      "disCompensation": disCompensation,
      "compensationMeter": compensationMeter,
      "includePoints": includePoints,
      "page": page,
      "limit": limit,
    });
    Result result = Result.fromJson(jsonDecode(json ?? "{}"));
    return result;
  }

}
